@@ -4,7 +4,7 @@
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow),
-    progress(tr("Setting up the theme, please wait..."), tr("Abort"), 0, 0, this),
+    progress(tr("Setting up the theme, please wait..."), tr("Abort"), 0, 100, this),
     progress2(tr("Searching and importing fonts, please wait..."), tr("Abort"), 0, 0, this),
     progress3(tr("Reading settings..."), tr("Abort"), 0, 100, this),
     progress4(tr("Restoring files, please wait..."), tr("Abort"), 0, 0, this),
@@ -21,6 +21,7 @@ MainWindow::MainWindow(QWidget *parent) :
     progress3.setValue(0);
     progress3.show();
     progress3.setValue(5);
+    lastpath = "/home/user/MyDocs";
     readdirs();
     oldfonts("/etc/hildon/theme/colors.config");
     progress3.setValue(20);
@@ -274,54 +275,153 @@ void MainWindow::on_pushButton_clicked()
         progress.setWindowModality(Qt::WindowModal);
         progress.setWindowTitle(varattu);
         progress.setCancelButton(0);
+        progress.show();
+        progress.setValue(2);
         QStringList arguments;
         arguments << ui->FontSize->currentText() << ui->Fonter->currentText() << ui->Iconset->currentText() << Icons << ui->lineEdit->text() << ui->Snap->text() << checkboxstate << fonts << f1 << f2 << f3 << f4 << ui->lineEdit_2->text() << f5 << f6 << f7 << f8 << ui->Opacity->text();
-        QProcess *process = new QProcess(this);
-        connect(process, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
-        process->start("/sbin/launchcustomizer", arguments);
-        progress.show();
 
-}
+//        QMaemo5InformationBox::information(this, tr("Creating backups..."), 1);
+        progress.setLabelText(tr("Creating backups..."));
+        sleep(2);
+        progress.setValue(4);
+        progress.setValue(6);
+        progress.setValue(8);
+        QStringList systemcommand;
+        systemcommand << "createbackups";
+        QProcess *muoks1 = new QProcess(this);
+        muoks1->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(10);
 
-void MainWindow::processFinished(int)
-{
-    int opasity = ui->Opacity->text().toInt();
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Setting up widget opacities...'");
-    SetOpacity("ApplicationShortcutApplet.png", opasity);
-    SetOpacity("CalendarAppletBackground.png", opasity);
-    SetOpacity("ContactsAppletFrame.png", opasity);
-    SetOpacity("MapAppletButton.png", opasity);
-    SetOpacity("MapAppletHead.png", opasity);
-    SetOpacity("MediaPlayerAppletHead.png", opasity);
-    SetOpacity("MediaPlayerAppletNext.png", opasity);
-    SetOpacity("MediaPlayerAppletPrevious.png", opasity);
-    SetOpacity("MediaPlayerAppletStopPlay.png", opasity);
-    SetOpacity("OviCenter.png", opasity);
-    SetOpacity("OviLeft.png", opasity);
-    SetOpacity("OviRight.png", opasity);
-    SetOpacity("RSSAppletHead.png", opasity);
-    SetOpacity("WebShortcutAppletBackground.png", opasity);
+//        QMaemo5InformationBox::information(this, tr("Setting up font family..."), 1);
+        progress.setLabelText(tr("Setting up font family..."));
+        sleep(2);
+        progress.setValue(12);
+        progress.setValue(14);
+        progress.setValue(16);
+        progress.setValue(18);
+        systemcommand.clear();
+        systemcommand << "setfontfamily" << ui->Fonter->currentText();
+        QProcess *muoks2 = new QProcess(this);
+        muoks2->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(20);
 
-    if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
+//        QMaemo5InformationBox::information(this, tr("Setting up font sizes..."), 1);
+        progress.setLabelText(tr("Setting up font sizes..."));
+        sleep(2);
+        progress.setValue(22);
+        progress.setValue(24);
+        progress.setValue(26);
+        progress.setValue(28);
+        systemcommand.clear();
+        systemcommand << "setfontsize" << ui->FontSize->currentText();
+        QProcess *muoks3 = new QProcess(this);
+        muoks3->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(30);
 
-        system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
-        system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Restarting hildon-home...'");
-        system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
-        system("sleep 2");
-        system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
-        system("sleep 2 && killall hildon-status-menu");
-        system("sleep 2 && killall systemui");
-        system("sleep 2 && killall hildon-desktop");
-        system("killall theme-customizer");
+//        QMaemo5InformationBox::information(this, tr("Setting up font colors..."), 1);
+        progress.setLabelText(tr("Setting up font colors..."));
+        sleep(2);
+        progress.setValue(32);
+        progress.setValue(34);
+        progress.setValue(36);
+        progress.setValue(38);
+        systemcommand.clear();
+        systemcommand << "setfontcolors" << f1 << f2 << f3 << f4 << f5 << f6 << f7 << f8;
+        QProcess *muoks4 = new QProcess(this);
+        muoks4->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(40);
 
-    } else {
+//        QMaemo5InformationBox::information(this, tr("Setting up icon theme..."), 1);
+        progress.setLabelText(tr("Setting up icon theme..."));
+        sleep(2);
+        progress.setValue(42);
+        progress.setValue(44);
+        progress.setValue(46);
+        progress.setValue(48);
+        systemcommand.clear();
+        systemcommand << "seticontheme" << ui->Iconset->currentText();
+        QProcess *muoks5 = new QProcess(this);
+        muoks5->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(50);
 
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
-    system("/sbin/launchcustomizer rebootnow");
-    progress.cancel();
-    // oldfonts();
+ //       QMaemo5InformationBox::information(this, tr("Setting up snap-to-grid..."), 1);
+        progress.setLabelText(tr("Setting up snap-to-grid..."));
+        sleep(2);
+        progress.setValue(52);
+        progress.setValue(54);
+        progress.setValue(56);
+        progress.setValue(58);
+        systemcommand.clear();
+        systemcommand << "setsnaptogrid" << ui->Snap->text();
+        QProcess *muoks6 = new QProcess(this);
+        muoks6->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(60);
+
+ //       QMaemo5InformationBox::information(this, tr("Setting up shortcut and bookmark sizes..."), 1);
+        progress.setLabelText(tr("Setting up shortcut and bookmark sizes..."));
+        sleep(2);
+        progress.setValue(62);
+        progress.setValue(64);
+        progress.setValue(66);
+        progress.setValue(68);
+        systemcommand.clear();
+        systemcommand << "seticonsizes" << ui->lineEdit->text() << ui->lineEdit_2->text() << Icons;
+        QProcess *muoks7 = new QProcess(this);
+        muoks7->start("/sbin/launchcustomizer", systemcommand);
+        progress.setValue(70);
+
+        int opasity = ui->Opacity->text().toInt();
+ //       QMaemo5InformationBox::information(this, tr("Setting up widget opacities..."), 1);
+        progress.setLabelText(tr("Setting up widget opacities..."));
+        sleep(2);
+        progress.setValue(72);
+        progress.setValue(74);
+        progress.setValue(76);
+        progress.setValue(78);
+        SetOpacity("ApplicationShortcutApplet.png", opasity);
+        SetOpacity("CalendarAppletBackground.png", opasity);
+        SetOpacity("ContactsAppletFrame.png", opasity);
+        SetOpacity("MapAppletButton.png", opasity);
+        SetOpacity("MapAppletHead.png", opasity);
+        SetOpacity("MediaPlayerAppletHead.png", opasity);
+        progress.setValue(80);
+        SetOpacity("MediaPlayerAppletNext.png", opasity);
+        SetOpacity("MediaPlayerAppletPrevious.png", opasity);
+        SetOpacity("MediaPlayerAppletStopPlay.png", opasity);
+        SetOpacity("OviCenter.png", opasity);
+        SetOpacity("OviLeft.png", opasity);
+        SetOpacity("OviRight.png", opasity);
+        SetOpacity("RSSAppletHead.png", opasity);
+        SetOpacity("WebShortcutAppletBackground.png", opasity);
+        progress.setValue(82);
+        progress.setValue(84);
+        progress.setValue(86);
+        progress.setValue(88);
+
+        if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
+
+            progress.setLabelText(tr("Restarting services..."));
+            QMaemo5InformationBox::information(this, tr("Restarting services..."), QMaemo5InformationBox::DefaultTimeout);
+            sleep(2);
+            system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
+            system("sleep 2");
+            system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
+            system("sleep 2 && killall hildon-status-menu");
+            system("sleep 2 && killall systemui");
+            progress.setValue(100);
+            system("sleep 2 && killall hildon-desktop");
+            system("killall theme-customizer");
+
+        } else {
+
+        system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
+        system("/sbin/launchcustomizer rebootnow");
+        progress.setValue(100);
+        progress.cancel();
+        // oldfonts();
+
+    }
 
-}
 
 }
 
@@ -502,8 +602,23 @@ void MainWindow::on_checkBoxActivate_stateChanged(int )
 
 void MainWindow::on_fontimport_triggered()
 {
+    QString fontdir = QFileDialog::getExistingDirectory(this, "Select folder containing fonts", lastpath, QFileDialog::ShowDirsOnly);
+    if (fontdir.isEmpty()) return;
 
-    QMessageBox msgBox;
+    lastpath = fontdir;
+    QString varattu2;
+    varattu2 = tr("Importing fonts");
+    progress2.setWindowModality(Qt::WindowModal);
+    progress2.setWindowTitle(varattu2);
+    progress2.setCancelButton(0);
+    QStringList arguments2;
+    arguments2 << "importfontspushed" << fontdir;
+    QProcess *process2 = new QProcess(this);
+    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
+    process2->start("/sbin/launchcustomizer", arguments2);
+    progress2.show();
+
+/*    QMessageBox msgBox;
     msgBox.setWindowTitle(tr("Theme Customizer - font import"));
     msgBox.setText(tr("Do you want to import fonts from MyDocs?"));
     msgBox.setInformativeText(tr("Note: this function will only import .ttf and .otf fonts from root of MyDocs"));
@@ -529,6 +644,7 @@ void MainWindow::on_fontimport_triggered()
 
     }
 
+*/
 }
 
 void MainWindow::process2Finished(int)
@@ -542,7 +658,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-23<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-24<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -631,10 +747,8 @@ void MainWindow::savedone()
     presetname.simplified();
     QFile file("/opt/theme-customizer/presets/" + presetname);
     if (presetname.isEmpty()) {
- //       system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'You must give name for the preset' uint32:0 string:'OK'");
 
-        QMaemo5InformationBox::information(this, "You must give name for the preset.",
-                                           QMaemo5InformationBox::DefaultTimeout);
+        QMaemo5InformationBox::information(this, tr("You must give name for the preset."), QMaemo5InformationBox::DefaultTimeout);
 
     } else if (file.exists()) {
         QMessageBox msgBox;
@@ -656,8 +770,7 @@ void MainWindow::savedone()
             // optional, as QFile destructor will already do it:
             file.close();
             SaveWin->hide();
-            QMaemo5InformationBox::information(this, "Preset saved!",
-                                               QMaemo5InformationBox::DefaultTimeout);
+            QMaemo5InformationBox::information(this, tr("Preset saved!"), QMaemo5InformationBox::DefaultTimeout);
 
         }
     } else {
@@ -668,8 +781,7 @@ void MainWindow::savedone()
         // optional, as QFile destructor will already do it:
         file.close();
         SaveWin->hide();
-        QMaemo5InformationBox::information(this, "Preset saved!",
-                                           QMaemo5InformationBox::DefaultTimeout);
+        QMaemo5InformationBox::information(this, tr("Preset saved!"), QMaemo5InformationBox::DefaultTimeout);
     }
 }
 
@@ -684,9 +796,9 @@ void MainWindow::on_pushButton_4_clicked()
 
 void MainWindow::loadclicked()
 {
-    if (ManWin->ui->presetslist->currentIndex() == 1) {
+    if (ManWin->ui->presetslist->currentRow() == 0) {
         loadpr = "/etc/hildon/theme/colors.config";
-    } else if (ManWin->ui->presetslist->currentIndex() == 2) {
+    } else if (ManWin->ui->presetslist->currentRow() == 1) {
         QString colorfile = QFileInfo("/etc/hildon/theme/colors.config").canonicalFilePath();
         QString originalcolorfile = "/opt/theme-customizer/backups/" + colorfile;
         if (QFile(originalcolorfile).exists()) {
@@ -695,17 +807,16 @@ void MainWindow::loadclicked()
             loadpr = "/etc/hildon/theme/colors.config";
         }
     } else {
-    loadpr = "/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText();
+    loadpr = "/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentItem()->text();
     }
     oldfonts(loadpr);
     ManWin->hide();
-    QMaemo5InformationBox::information(this, "Preset loaded.",
-                                       QMaemo5InformationBox::DefaultTimeout);
+    QMaemo5InformationBox::information(this, tr("Preset loaded."), QMaemo5InformationBox::DefaultTimeout);
 }
 
 void MainWindow::delclicked()
 {
-    QFile file("/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText());
+    QFile file("/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentItem()->text());
     QMessageBox msgBox;
     msgBox.setWindowTitle(tr("Delete color preset?"));
     msgBox.setText(tr("Are you sure you want to delete this preset?"));
@@ -719,8 +830,7 @@ void MainWindow::delclicked()
 
         if (file.exists()) file.remove();
         ManWin->hide();
-        QMaemo5InformationBox::information(this, "Preset deleted.",
-                                           QMaemo5InformationBox::DefaultTimeout);
+        QMaemo5InformationBox::information(this, tr("Preset deleted."), QMaemo5InformationBox::DefaultTimeout);
 
     }
 }
