@@ -20,6 +20,7 @@
 #include "managepresets.h"
 #include "ui_managepresets.h"
 #include <QtMaemo5/QMaemo5InformationBox>
+#include <QFileDialog>
 
 namespace Ui {
     class MainWindow;
@@ -58,6 +59,7 @@ private:
     QString f6;
     QString f7;
     QString f8;
+    QString lastpath;
     backgrounds* newWin;
     savepreset* SaveWin;
     managepresets* ManWin;
@@ -98,7 +100,7 @@ private slots:
     void on_fontprimary_clicked();
     void on_horizontalSlider_valueChanged(int);
     void on_pushButton_clicked();
-    void processFinished(int exitCode);
+//    void processFinished(int exitCode);
     void process2Finished(int exitCode);
     void process2Finished2(int exitCode);
 };
