@@ -18,6 +18,71 @@
         <source>Theme Customizer - restore files</source>
         <translation>Theme Customizer - tiedostojen palautus</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the preset.</source>
+        <translation>Presetille on annettava nimi.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset saved!</source>
+        <translation>Presetti tallennettu!</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset loaded.</source>
+        <translation>Presetti ladattu.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset deleted.</source>
+        <translation>Presetti poistettu.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Creating backups...</source>
+        <translation>Luodaan varmuuskopioita...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font family...</source>
+        <translation>Asetetaan fontin tyyli...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font sizes...</source>
+        <translation>Asetetaan fonttien koot...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font colors...</source>
+        <translation>Asetetaan fonttien värit...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up icon theme...</source>
+        <translation>Asetetaan ikonien teema...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up snap-to-grid...</source>
+        <translation>Asetetaan snap-to-grid arvo...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up shortcut and bookmark sizes...</source>
+        <translation>Asetetaan kuvakkeiden kokoja...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up widget opacities...</source>
+        <translation>Asetetaan widgettien läpinäkyvyydet...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services...</source>
+        <translation>Uudelleenkäynnistetään palveluja...</translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files, please wait...</source>
@@ -236,8 +301,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="780"/>
-        <source>Import fonts from MyDocs</source>
-        <translation>Tuo fontteja MyDocs:sta</translation>
+        <source>Import fonts from folder</source>
+        <translation>Tuo fontteja kansiosta</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="783"/>
