@@ -11,27 +11,92 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Restore theme files</source>
+        <translation>Restaurer les fichiers du thème</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Creating backups...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the preset.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset saved!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset loaded.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset deleted.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font family...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font sizes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font colors...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up icon theme...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up snap-to-grid...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up shortcut and bookmark sizes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up widget opacities...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files, please wait...</source>
-        <translation type="unfinished"></translation>
+        <translation>Restauration des fichiers, patientez svp...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Theme Customizer - restore files</source>
-        <translation type="unfinished"></translation>
+        <translation>Theme Customizer - Restaure les fichiers</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Do you want to restore all original theme files?</source>
-        <translation type="unfinished"></translation>
+        <translation>Voulez-vous restaurer tous les fichiers original du thème?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files from backup</source>
-        <translation type="unfinished"></translation>
+        <translation>Restauration des fichiers depuis la sauvegarde</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
@@ -236,7 +301,7 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="780"/>
-        <source>Import fonts from MyDocs</source>
+        <source>Import fonts from folder</source>
         <translation>Importer des fontes</translation>
     </message>
     <message>
