@@ -6,87 +6,152 @@
     <message>
         <location filename="mainwindow.ui" line="14"/>
         <source>Theme Customizer</source>
-        <translation type="unfinished"></translation>
+        <translation>Theme Customizer</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Restore theme files</source>
+        <translation>Restaurar archivos del tema</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Creating backups...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the preset.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset saved!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset loaded.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset deleted.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font family...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font sizes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font colors...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up icon theme...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up snap-to-grid...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up shortcut and bookmark sizes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up widget opacities...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files, please wait...</source>
-        <translation type="unfinished"></translation>
+        <translation>Restaurando archivos, por favor espere...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Theme Customizer - restore files</source>
-        <translation type="unfinished"></translation>
+        <translation>Theme Customizer - Restaurar</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Do you want to restore all original theme files?</source>
-        <translation type="unfinished"></translation>
+        <translation>Desea restaurar los archivos originales del tema?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files from backup</source>
-        <translation type="unfinished"></translation>
+        <translation>Restaurando archivos desde backup</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings...</source>
-        <translation type="unfinished"></translation>
+        <translation>Leyendo cofiguración...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Leyendo configuración</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Ok, thanks.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ok, gracias.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Overwrite color preset?</source>
-        <translation type="unfinished"></translation>
+        <translation>Sobreescribir color predefinido?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Color preset with this name already exists, do you want to overwrite it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Ya existe un color predefinido con ese nombre, desea sobreescribirlo?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Si</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>No</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Delete color preset?</source>
-        <translation type="unfinished"></translation>
+        <translation>Borrar color predefinido?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Are you sure you want to delete this preset?</source>
-        <translation type="unfinished"></translation>
+        <translation>Esta seguro que desea borrar esta predefinición?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Color presets</source>
-        <translation type="unfinished"></translation>
+        <translation>Colores predefinidos</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Save color preset</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar color predefinido</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="81"/>
@@ -106,32 +171,32 @@
     <message>
         <location filename="mainwindow.ui" line="152"/>
         <source>-5</source>
-        <translation></translation>
+        <translation>-5</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="157"/>
         <source>-3</source>
-        <translation></translation>
+        <translation>-3</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="162"/>
         <source>-1</source>
-        <translation></translation>
+        <translation>-1</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="167"/>
         <source>+1</source>
-        <translation></translation>
+        <translation>+1</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="172"/>
         <source>+3</source>
-        <translation></translation>
+        <translation>+3</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="177"/>
         <source>+5</source>
-        <translation></translation>
+        <translation>+5</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="192"/>
@@ -151,7 +216,7 @@
     <message>
         <location filename="mainwindow.ui" line="260"/>
         <source>Active font</source>
-        <translation>Activa</translation>
+        <translation>Activo</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="278"/>
@@ -166,14 +231,12 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Button font</source>
-        <translation type="unfinished">
-</translation>
+        <translation>Botón</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Button pressed</source>
-        <translation type="unfinished">
-</translation>
+        <translation>Botón presionado</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="394"/>
@@ -193,17 +256,17 @@
     <message>
         <location filename="mainwindow.ui" line="482"/>
         <source>Show app shortcut backgrounds</source>
-        <translation>Mostrar fondo de íconos</translation>
+        <translation>Fondo de íconos</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="508"/>
         <source>Snap-to-grid size</source>
-        <translation>Tamaño de ajuste a cuadrícula</translation>
+        <translation>Ajuste a cuadrícula</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Widget opacity</source>
-        <translation type="unfinished"></translation>
+        <translation>Opacidad de fondo</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
@@ -234,22 +297,22 @@
     <message>
         <location filename="mainwindow.ui" line="771"/>
         <source>Test</source>
-        <translation type="unfinished">Menu</translation>
+        <translation>Testeo</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="780"/>
-        <source>Import fonts from MyDocs</source>
-        <translation type="unfinished">Import Fonts from MyDocs</translation>
+        <source>Import fonts from folder</source>
+        <translation>Imporar fuentes</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="783"/>
         <source>Import all font files from MyDocs</source>
-        <translation type="unfinished">Import all font files from MyDocs</translation>
+        <translation>Instalar todas las fuentes desde MyDocs</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="788"/>
         <source>About</source>
-        <translation type="unfinished">About</translation>
+        <translation>Acerca</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
@@ -275,7 +338,7 @@
     <message>
         <location filename="mainwindow.cpp" line="349"/>
         <source>Save and reboot</source>
-        <translation type="unfinished">Save and reboot</translation>
+        <translation>Guardar y reiniciar</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="360"/>
@@ -300,7 +363,7 @@
     <message>
         <location filename="mainwindow.cpp" line="393"/>
         <source>About Theme Customizer</source>
-        <translation type="unfinished">About Theme Customizer</translation>
+        <translation>Acerca de Theme Customizer</translation>
     </message>
 </context>
 <context>
@@ -308,37 +371,37 @@
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Reloj</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>App Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Admin Aplicaciones</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Media Player</source>
-        <translation type="unfinished"></translation>
+        <translation>Reproductor</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Lockscreen</source>
-        <translation type="unfinished"></translation>
+        <translation>Pant Bloqueo</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Tap me to change</source>
-        <translation type="unfinished"></translation>
+        <translation>Tocar para cambiar</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Set image</source>
-        <translation type="unfinished"></translation>
+        <translation>Definir imagen</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Backgrounds</source>
-        <translation type="unfinished"></translation>
+        <translation>Fondos</translation>
     </message>
 </context>
 <context>
@@ -346,17 +409,17 @@
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save color preset as...</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar color predefinido como...</translation>
     </message>
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar</translation>
     </message>
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save color preset</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar color predefinido</translation>
     </message>
 </context>
 <context>
@@ -364,32 +427,32 @@
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Choose color preset:</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar color predefinido:</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Currently active colors</source>
-        <translation type="unfinished"></translation>
+        <translation>Colores activos</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Load</source>
-        <translation type="unfinished"></translation>
+        <translation>Cargar</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Borrar</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Manage color presets</source>
-        <translation type="unfinished"></translation>
+        <translation>Administrar colores</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Original colors of current theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Colores originales del tema actual</translation>
     </message>
 </context>
 </TS>
