@@ -11,82 +11,147 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Restore theme files</source>
+        <translation>Återställ temafiler</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Creating backups...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the preset.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset saved!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset loaded.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Preset deleted.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font family...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font sizes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up font colors...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up icon theme...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up snap-to-grid...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up shortcut and bookmark sizes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Setting up widget opacities...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files, please wait...</source>
-        <translation type="unfinished"></translation>
+        <translation>Återställer filer, vänta...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Theme Customizer - restore files</source>
-        <translation type="unfinished"></translation>
+        <translation>Theme Customizer - återställ filer</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Do you want to restore all original theme files?</source>
-        <translation type="unfinished"></translation>
+        <translation>Vill du återställa alla orginaltemafiler?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restoring files from backup</source>
-        <translation type="unfinished"></translation>
+        <translation>Återställer filer från säkerhetskopia</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings...</source>
-        <translation type="unfinished"></translation>
+        <translation>Läser inställningar...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Reading settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Läser inställningar</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Ok, thanks.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ok, tack.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Overwrite color preset?</source>
-        <translation type="unfinished"></translation>
+        <translation>Skriva över färgsättning?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Color preset with this name already exists, do you want to overwrite it?</source>
-        <translation type="unfinished"></translation>
+        <translation>En färgsättning med detta namn finns redan, vill du skriva över den?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>Ja</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>No</source>
-        <translation type="unfinished"></translation>
+        <translation>Nej</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Delete color preset?</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta bort färgsättning?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Are you sure you want to delete this preset?</source>
-        <translation type="unfinished"></translation>
+        <translation>Är du säker på att du vill ta bort denna färgsättning?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Color presets</source>
-        <translation type="unfinished"></translation>
+        <translation>Färgsättningar</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Save color preset</source>
-        <translation type="unfinished"></translation>
+        <translation>Spara färgsättning</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="81"/>
@@ -201,7 +266,7 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Widget opacity</source>
-        <translation type="unfinished"></translation>
+        <translation>Widgetgenomskinlighet</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="560"/>
@@ -236,8 +301,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="780"/>
-        <source>Import fonts from MyDocs</source>
-        <translation>Importera teckensnitt från MyDocs</translation>
+        <source>Import fonts from folder</source>
+        <translation>Importera teckensnitt</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="783"/>
@@ -306,37 +371,37 @@
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Clock</source>
-        <translation type="unfinished"></translation>
+        <translation>Klocka</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>App Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Programhanterare</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Media Player</source>
-        <translation type="unfinished"></translation>
+        <translation>Mediaspelare</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Lockscreen</source>
-        <translation type="unfinished"></translation>
+        <translation>Skärmlås</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Tap me to change</source>
-        <translation type="unfinished"></translation>
+        <translation>Klicka för att ändra</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Set image</source>
-        <translation type="unfinished"></translation>
+        <translation>Ställ in bild</translation>
     </message>
     <message>
         <location filename="backgrounds.ui" line="0"/>
         <source>Backgrounds</source>
-        <translation type="unfinished"></translation>
+        <translation>Bakgrunder</translation>
     </message>
 </context>
 <context>
@@ -344,17 +409,17 @@
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save color preset as...</source>
-        <translation type="unfinished"></translation>
+        <translation>Spara färgsättning som... </translation>
     </message>
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Spara</translation>
     </message>
     <message>
         <location filename="savepreset.ui" line="0"/>
         <source>Save color preset</source>
-        <translation type="unfinished"></translation>
+        <translation>Spara färgsättning</translation>
     </message>
 </context>
 <context>
@@ -362,32 +427,32 @@
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Choose color preset:</source>
-        <translation type="unfinished"></translation>
+        <translation>Välj färgsättning:</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Currently active colors</source>
-        <translation type="unfinished"></translation>
+        <translation>Nuvarande aktiva färger</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Load</source>
-        <translation type="unfinished"></translation>
+        <translation>Ladda</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta bort</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Manage color presets</source>
-        <translation type="unfinished"></translation>
+        <translation>Hantera färgsättningar</translation>
     </message>
     <message>
         <location filename="managepresets.ui" line="0"/>
         <source>Original colors of current theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Orginalfärger för nuvarnade tema</translation>
     </message>
 </context>
 </TS>
